Agent Dev Loop

# Config Builder

Base Config

## Model Settings

Model
Temperature
System Prompt You are an expert assistant. Think step by step and provide detailed explanations.

## Environment Settings

## Evaluation Settings

Max Turns
Num Samples

## Tools

Select a base config to see available tools, or add custom tools below.

## Save Config

Config Name

# Evaluation Results

- Loading traces...

Select an evaluation to view details